@@ -27,23 +27,24 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <boost/thread.hpp>
-#include <boost/bind.hpp>
+#include <chrono>
+#include <cstddef>
+#include <functional>
 #include <iostream>
 #include <string>
+#include <thread>
 #include <vector>
 
-#include "class_loader/class_loader.h"
-#include "class_loader/multi_library_class_loader.h"
+#include "class_loader/class_loader.hpp"
+#include "class_loader/multi_library_class_loader.hpp"
 
 #include "gtest/gtest.h"
 
-#include "./base.h"
+#include "./base.hpp"
 
-const char LIBRARY_1[] = "libclass_loader_TestPlugins1.so";
-const char LIBRARY_2[] = "libclass_loader_TestPlugins2.so";
+const std::string LIBRARY_1 = class_loader::systemLibraryFormat("class_loader_TestPlugins1");  // NOLINT
+const std::string LIBRARY_2 = class_loader::systemLibraryFormat("class_loader_TestPlugins2");  // NOLINT
 
-/*****************************************************************************/
 TEST(ClassLoaderTest, basicLoad) {
   try {
     class_loader::ClassLoader loader1(LIBRARY_1, false);
@@ -55,15 +56,14 @@ TEST(ClassLoaderTest, basicLoad) {
   SUCCEED();
 }
 
-/*****************************************************************************/
 TEST(ClassLoaderTest, correctNonLazyLoadUnload) {
   try {
-    ASSERT_FALSE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_FALSE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     class_loader::ClassLoader loader1(LIBRARY_1, false);
-    ASSERT_TRUE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_TRUE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     ASSERT_TRUE(loader1.isLibraryLoaded());
     loader1.unloadLibrary();
-    ASSERT_FALSE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_FALSE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     ASSERT_FALSE(loader1.isLibraryLoaded());
     return;
   } catch (class_loader::ClassLoaderException & e) {
@@ -73,22 +73,21 @@ TEST(ClassLoaderTest, correctNonLazyLoadUnload) {
   }
 }
 
-/*****************************************************************************/
 TEST(ClassLoaderTest, correctLazyLoadUnload) {
   try {
-    ASSERT_FALSE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_FALSE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     class_loader::ClassLoader loader1(LIBRARY_1, true);
-    ASSERT_FALSE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_FALSE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     ASSERT_FALSE(loader1.isLibraryLoaded());
 
     {
       boost::shared_ptr<Base> obj = loader1.createInstance<Base>("Cat");
-      ASSERT_TRUE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+      ASSERT_TRUE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
       ASSERT_TRUE(loader1.isLibraryLoaded());
     }
 
     // The library will unload automatically when the only plugin object left is destroyed
-    ASSERT_FALSE(class_loader::class_loader_private::isLibraryLoadedByAnybody(LIBRARY_1));
+    ASSERT_FALSE(class_loader::impl::isLibraryLoadedByAnybody(LIBRARY_1));
     return;
   } catch (class_loader::ClassLoaderException & e) {
     FAIL() << "ClassLoaderException: " << e.what() << "\n";
@@ -97,14 +96,12 @@ TEST(ClassLoaderTest, correctLazyLoadUnload) {
   }
 }
 
-/*****************************************************************************/
-
 TEST(ClassLoaderTest, nonExistentPlugin) {
   class_loader::ClassLoader loader1(LIBRARY_1, false);
 
   try {
     boost::shared_ptr<Base> obj = loader1.createInstance<Base>("Bear");
-    if (NULL == obj) {
+    if (nullptr == obj) {
       FAIL() << "Null object being returned instead of exception thrown.";
     }
 
@@ -119,7 +116,6 @@ TEST(ClassLoaderTest, nonExistentPlugin) {
   FAIL() << "Did not throw exception as expected.\n";
 }
 
-/*****************************************************************************/
 TEST(ClassLoaderTest, nonExistentLibrary) {
   try {
     class_loader::ClassLoader loader1("libDoesNotExist.so", false);
@@ -133,8 +129,6 @@ TEST(ClassLoaderTest, nonExistentLibrary) {
   FAIL() << "Did not throw exception as expected.\n";
 }
 
-/*****************************************************************************/
-
 class InvalidBase
 {
 };
@@ -157,18 +151,16 @@ TEST(ClassLoaderTest, invalidBase) {
   }
 }
 
-/*****************************************************************************/
-
 void wait(int seconds)
 {
-  boost::this_thread::sleep(boost::posix_time::seconds(seconds));
+  std::this_thread::sleep_for(std::chrono::seconds(seconds));
 }
 
 void run(class_loader::ClassLoader * loader)
 {
   std::vector<std::string> classes = loader->getAvailableClasses<Base>();
-  for (unsigned int c = 0; c < classes.size(); c++) {
-    loader->createInstance<Base>(classes.at(c))->saySomething();
+  for (auto & class_ : classes) {
+    loader->createInstance<Base>(class_)->saySomething();
   }
 }
 
@@ -180,18 +172,18 @@ TEST(ClassLoaderTest, threadSafety) {
   // The hope is this test is hard enough that once in a while it'll segfault
   // or something if there's some implementation error.
   try {
-    std::vector<boost::thread *> client_threads;
+    std::vector<std::thread *> client_threads;
 
-    for (unsigned int c = 0; c < 1000; c++) {
-      client_threads.push_back(new boost::thread(boost::bind(&run, &loader1)));
+    for (size_t c = 0; c < 1000; c++) {
+      client_threads.push_back(new std::thread(std::bind(&run, &loader1)));
     }
 
-    for (unsigned int c = 0; c < client_threads.size(); c++) {
-      client_threads.at(c)->join();
+    for (auto & client_thread : client_threads) {
+      client_thread->join();
     }
 
-    for (unsigned int c = 0; c < client_threads.size(); c++) {
-      delete (client_threads.at(c));
+    for (auto & client_thread : client_threads) {
+      delete (client_thread);
     }
 
     loader1.unloadLibrary();
@@ -203,8 +195,6 @@ TEST(ClassLoaderTest, threadSafety) {
   }
 }
 
-/*****************************************************************************/
-
 TEST(ClassLoaderTest, loadRefCountingNonLazy) {
   try {
     class_loader::ClassLoader loader1(LIBRARY_1, false);
@@ -239,8 +229,6 @@ TEST(ClassLoaderTest, loadRefCountingNonLazy) {
   FAIL() << "Did not throw exception as expected.\n";
 }
 
-/*****************************************************************************/
-
 TEST(ClassLoaderTest, loadRefCountingLazy) {
   try {
     class_loader::ClassLoader loader1(LIBRARY_1, true);
@@ -281,9 +269,6 @@ TEST(ClassLoaderTest, loadRefCountingLazy) {
   FAIL() << "Did not throw exception as expected.\n";
 }
 
-
-/*****************************************************************************/
-
 void testMultiClassLoader(bool lazy)
 {
   try {
@@ -333,8 +318,6 @@ TEST(MultiClassLoaderTest, noWarningOnLazyLoad) {
   SUCCEED();
 }
 
-/*****************************************************************************/
-
 // Run all the tests that were declared with TEST()
 int main(int argc, char ** argv)
 {
